@@ -37,7 +37,7 @@ class ArtifactEntry:
         assert_that(local_root_path).is_not_none()
         assert_that(artifact_id).is_not_none()
 
-        local_path = os.path.join(local_root_path, self.path)
+        local_path = os.path.join(local_root_path, self.repo_tag, self.path)
         if sys.platform.startswith('win32'):
             # 윈도우인 경우 Path Seperator를 리눅스 형식으로 강제로 변경함
             local_path = local_path.replace("\\", "/")
@@ -249,7 +249,7 @@ class Artifacts:
 
     # Artifact 객체를 기반으로 Artifact에 등록된 모든 엔트리의 다운로드 수행
     def download(self) -> str:
-        # ./deepdriver/artifact/{artifact_id}/ 폴더가 생성된다
+        # ./deepdriver/artifact/{artifact_id}/{tag} 폴더가 생성된다
         local_root_path = os.path.join(".", "deepdriver", "artifact", str(self.id))
 
 
